<?php

namespace simply_static_pro\commands\deployment;

use simply_static_pro\commands\Update_Command;

class Bunny_CDN extends Update_Command {

	protected $section = 'deployment';

	protected $name = 'bunny-cdn';

	protected $option_name = '';

	protected $description = 'Setup Bunny CDN.';

	public function get_synopsis() {
		$fields = $this->get_fields();

		$synopsis = [
			[
				'type'        => 'assoc',
				'name'        => 'field',
				'description' => "You can skip the whole setup and use this for specific fields.\nAvailable fields: \n" . array_reduce( array_keys( $fields ), function ( $carry, $item ) use ( $fields ) {
						return $carry .= '- ' . \WP_CLI::colorize( '%Y' . $item . '%n' ) . ': ' . $fields[ $item ]['desc'] . "\n";
					} ),
				'optional'    => true,
				'repeating'   => false,
			],
			[
				'type'        => 'assoc',
				'name'        => 'value',
				'description' => "The field Value that will be saved. This is required if using --field",
				'optional'    => true,
				'repeating'   => false,
			]
		];

		return array_merge( $synopsis, parent::get_synopsis() ); // TODO: Change the autogenerated stub
	}

	protected function get_fields() {
		return [
			'api-key'      => [
				'field' => 'api-key',
				'name'  => 'cdn_api_key',
				'label' => 'CDN API Key',
				'desc'  => "Enter your API Key for your CDN Provider."
			],
			'storage-host' => [
				'field' => 'storage-host',
				'name'  => 'cdn_storage_host',
				'label' => 'Storage Host',
				'desc'  => "Depending on your location, you have a different storage host."
			],
			'access-key'   => [
				'field' => 'access-key',
				'name'  => 'cdn_access_key',
				'label' => 'CDN Access Key',
				'desc'  => "Enter your Access Key. For BunnyCDN you will find it within your storage zone settings within FTP & API Access -> Password."
			],
			'pull-zone'    => [
				'field' => 'pull-zone',
				'name'  => 'cdn_pull_zone',
				'label' => 'Pull Zone',
				'desc'  => "A pull zone is the connection of your CDN to the internet. Simply Static will try to find an existing pull zone with the provided name, if there is none it creates a new pull zone."
			],
			'storage-zone' => [
				'field' => 'storage-zone',
				'name'  => 'cdn_storage_zone',
				'label' => 'Storage Host',
				'desc'  => "A storage zone contains your static files. Simply Static will try to find an existing storage zone with the provided name, if there is none it creates a new storage zone."
			],
			'directory'    => [
				'field' => 'directory',
				'name'  => 'cdn_directory',
				'label' => 'Directory',
				'desc'  => "[OPTIONAL] If you want to transfer the files to a specific sub directory on your storage zone add the name of that directory here."
			],
			'404'          => [
				'field' => '404',
				'name'  => 'cdn_404',
				'label' => '404',
				'desc'  => "Relative path to your custom 404 page. For example /custom-404/"
			],
		];
	}

	/**
	 * Run
	 *
	 * @param $args
	 * @param $options
	 *
	 * @return void
	 */
	public function run( $args, $options ) {

		$fields = $this->get_fields();

		if ( isset( $options['field'] ) ) {
			if ( ! isset( $fields[ $options['field'] ] ) ) {
				\WP_CLI::error( 'Not an existing field.' );

				return;
			}

			if ( ! isset( $options['value'] ) ) {
				\WP_CLI::error( 'Please provide a value for the field. Use --value to set it.' );

				return;
			}

			$this->update( $options['value'], $fields[ $options['field'] ]['name'] );
			\WP_CLI::success( 'Updated!' );

			return;
		}

		foreach ( $fields as $field ) {
			$value = $this->ask( 'Please enter value for ' . \WP_CLI::colorize( '%Y' . $field['label'] . '%n' ) . "\n" . $field['desc'] . "\nTo remove data from existing field just hit Enter.\n" );
			$this->update( $value, $field['name'] );
			\WP_CLI::success( 'Updated ' . $field['label'] . '!' );
		}
	}
}